@@ -1,6 +1,6 @@
 # -*- python -*-
 
-# Copyright (C) 1998-2016 by the Free Software Foundation, Inc.
+# Copyright (C) 1998-2018 by the Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -131,14 +131,50 @@ SUBSCRIBE_FORM_SECRET = None
 # test.
 SUBSCRIBE_FORM_MIN_TIME = seconds(5)
 
+# Use a custom question-answer CAPTCHA to protect against subscription spam.
+# Has no effect unless SUBSCRIBE_FORM_SECRET is set.
+# Should be set to a dict mapping language keys to a list of pairs
+# of questions and regexes for the answers, e.g.
+# CAPTCHAS = {
+#   'en': [
+#     ('What is two times six?', '(12|twelve)'),
+#     ('What is this mailing list software called?', '[Mm]ailman'),
+#   ],
+#   'de': [
+#     ('Was ist 3 mal 6?', '(18|achtzehn)'),
+#   ],
+# }
+# The regular expression must match the full string, i.e., it is implicitly
+# acting as if it had "^" in the beginning and "$" at the end.
+# An 'en' key must be present and is used as fall-back if there are no
+# questions for the currently set language.
+CAPTCHAS = None
+
+# Use Google reCAPTCHA to protect the subscription form from spam bots.  The
+# following must be set to a pair of keys issued by the reCAPTCHA service at
+# https://www.google.com/recaptcha/admin
+RECAPTCHA_SITE_KEY = None
+RECAPTCHA_SECRET_KEY = None
+
 # Installation wide ban list.  This is a list of email addresses and regexp
 # patterns (beginning with ^) which are not allowed to subscribe to any lists
 # in the installation.  This supplements the individual list's ban_list.
 # For example, to ban xxx@aol.com and any @gmail.com address beginning with
 # yyy, set
-# GLOBAL_BAN_LIST = ['xxx@aol.com', '^yyy.*@gmail\.com$']
+# GLOBAL_BAN_LIST = ['xxx@aol\.com', '^yyy.*@gmail\.com$']
 GLOBAL_BAN_LIST = []
 
+# If the following is set to Yes, and a web subscribe comes from an IPv4
+# address and the IP is listed in Spamhaus SBL, CSS or XBL, the subscription
+# will be blocked.  It will work with IPv6 addresses if Python's py2-ipaddress
+# module is installed.  The module can be installed via pip if not included
+# in your Python.
+BLOCK_SPAMHAUS_LISTED_IP_SUBSCRIBE = No
+
+# If the following is set to Yes, and a subscriber uses a domain that is
+# listed in the Spamhaus DBL, the subscription will be blocked.
+BLOCK_SPAMHAUS_LISTED_DBL_SUBSCRIBE = No
+
 # Command that is used to convert text/html parts into plain text.  This
 # should output results to standard output.  %(filename)s will contain the
 # name of the temporary file that the program should operate on.
@@ -149,6 +185,15 @@ HTML_TO_PLAIN_TEXT_COMMAND = '/usr/bin/lynx -dump %(filename)s'
 # character that doesn't match this class.  Do not include '/' in this list.
 ACCEPTABLE_LISTNAME_CHARACTERS = '[-+_.=a-z0-9]'
 
+# The number of characters in the longest listname in the installation.  The
+# fix for LP: #1780874 truncates list names in web URLs to this length to avoid
+# a content spoofing vulnerability.  If this is left at its default value of
+# 0, the length of the longest listname is calculated on every web access.
+# This can have performance implications in installations with a very large
+# number of lists.  To use this feature to avoid the calculation, set this to
+# a number equal to the length of the longest expected valid list name.
+MAX_LISTNAME_LENGTH = 0
+
 # Shall the user's real names be displayed along with their email addresses
 # in list rosters?  Defaults to No to preserve prior behavior.
 ROSTER_DISPLAY_REALNAME = No
@@ -185,7 +230,7 @@ VIRTUAL_HOST_OVERVIEW = On
 # omitted it defaults to urlhost with the first name stripped off, e.g.
 #
 # add_virtualhost('www.dom.ain')
-# VIRTUAL_HOST['www.dom.ain']
+# VIRTUAL_HOSTS['www.dom.ain']
 # ==> 'dom.ain'
 #
 def add_virtualhost(urlhost, emailhost=None):
@@ -218,6 +263,13 @@ add_virtualhost(DEFAULT_URL_HOST, DEFAULT_EMAIL_HOST)
 # -owners address, unless the message is explicitly approved.
 KNOWN_SPAMMERS = []
 
+# The header_filter_rules in Privacy options... -> Spam filters are matched as
+# normalized unicodes against normalized unicode headers.  This setting
+# determines the normalization form.  It is one of 'NFC', 'NFD', 'NFKC' or
+# 'NFKD'.  See
+# https://docs.python.org/2/library/unicodedata.html#unicodedata.normalize
+NORMALIZE_FORM = 'NFKC'
+
 
 
 #####
@@ -469,6 +521,12 @@ PUBLIC_MBOX = No
 #DELIVERY_MODULE = 'Sendmail'
 DELIVERY_MODULE = 'SMTPDirect'
 
+# Sometimes there are 'low level' smtplib failures that are difficult to
+# debug.  To enable very verbose debugging info from smtplib to Mailman's
+# error log, set the following to 1.  This will only work if
+# DELIVERY_MODULE = 'SMTPDirect' and Python is >= 2.4.
+SMTPLIB_DEBUG_LEVEL = 0
+
 # MTA should name a module in Mailman/MTA which provides the MTA specific
 # functionality for creating and removing lists.  Some MTAs like Exim can be
 # configured to automatically recognize new lists, in which case the MTA
@@ -556,6 +614,22 @@ SMTPPORT = 0                                      # default from smtplib
 # when DELIVERY_MODULE is 'Sendmail'.
 SENDMAIL_CMD = '/usr/lib/sendmail'
 
+# SMTP authentication for DELIVERY_MODULE = 'SMTPDirect'.  To enable SASL
+# authentication for SMTPDirect, set SMTP_AUTH = Yes and provide appropriate
+# settings for SMTP_USER and SMTP_PASSWD.
+SMTP_AUTH = No
+SMTP_USER = ''
+SMTP_PASSWD = ''
+
+# If using SASL authentication (SMTP_AUTH = Yes), set the following to Yes
+# to also use TLS. This has no effect if SMTP_AUTH = No.
+SMTP_USE_TLS = No
+
+# When using TLS the following should be set to the hostname that should be
+# used in order to identify Mailman to the SMTP server.  By default, it
+# uses DEFAULT_URL_HOST. Normally, you should not change this.
+SMTP_HELO_HOST = DEFAULT_URL_HOST
+
 # Set these variables if you need to authenticate to your NNTP server for
 # Usenet posting or reading.  If no authentication is necessary, specify None
 # for both variables.
@@ -594,10 +668,23 @@ NNTP_REWRITE_DUPLICATE_HEADERS = [
 # broken and even if the outgoing message is resigned.  However, some sites
 # may wish to remove these headers.  Possible values and meanings are:
 # No, 0, False -> do not remove headers.
-# Yes, 1, True -> remove headers only if the list's from_is_list setting is 1.
+# Yes, 1, True -> remove headers only if we are munging the from header due
+#                 to from_is_list or dmarc_moderation_action.
 # 2 -> always remove headers.
+# 3 -> always remove, rename and preserve original DKIM headers.
 REMOVE_DKIM_HEADERS = No
 
+# If the following is set to a non-empty string, that string is the name of a
+# header that will be added to personalized and VERPed deliveries with value
+# equal to the base64 encoding of the recipient's email address.  This is
+# intended to enable identification of the recipient otherwise redacted from
+# "spam report" feedback loop messages.  For example, if
+# RCPT_BASE64_HEADER_NAME = 'X-Mailman-R-Data'
+# a header like
+# X-Mailman-R-Data: dXNlckBleGFtcGxlLmNvbQo=
+# will be added to messages sent to user@@example.com.
+RCPT_BASE64_HEADER_NAME = ''
+
 # All `normal' messages which are delivered to the entire list membership go
 # through this pipeline of handler modules.  Lists themselves can override the
 # global pipeline by defining a `pipeline' attribute.
@@ -635,7 +722,6 @@ GLOBAL_PIPELINE = [
 OWNER_PIPELINE = [
     'SpamDetect',
     'Replybot',
-    'CleanseDKIM',
     'OwnerRecips',
     'ToOutgoing',
     ]
@@ -755,7 +841,10 @@ VERP_PROBES = No
 
 # A perfect opportunity for doing VERP is the password reminders, which are
 # already addressed individually to each recipient.  Set this to Yes to enable
-# VERPs on all password reminders.
+# VERPs on all password reminders.  However, because password reminders are
+# sent from the site list and site list bounces aren't processed but are just
+# forwarded to the site list admins, this isn't too useful.  See comments at
+# lines 70-84 of Mailman/Queue/BounceRunner.py for why we don't process them.
 VERP_PASSWORD_REMINDERS = No
 
 # Another good opportunity is when regular delivery is personalized.  Here
@@ -1036,6 +1125,18 @@ ANONYMOUS_LIST_KEEP_HEADERS = ['^(?!x-)', '^x-mailman-',
                                '^x-ack:', '^x-beenthere:',
                                '^x-list-administrivia:', '^x-spam-',
                               ]
+#
+# It is possible to mailbomb a third party by repeatrdly posting the subscribe
+# form.  You can prevent this by setting the following to Yes which will refuse
+# pending a subscription confirmation when one is already pending.  The down
+# side to this is if a subscriber loses or doesn't receive the confirmation
+# request email, she has to wait PENDING_REQUEST_LIFE (default 3 days) before
+# she can request another.  This setting also applies to repeated unsubscribes.
+REFUSE_SECOND_PENDING = No
+# Mailbombing of a list member of a list with private rosters can occur with
+# repeated subscribe attempts resulting in repeated user warnings.  Set the
+# following to No to supress the user warnings.
+WARN_MEMBER_OF_SUBSCRIBE = Yes
 
 
 
@@ -1057,7 +1158,7 @@ DEFAULT_MAX_MESSAGE_SIZE = 40           # KB
 DEFAULT_SUBJECT_PREFIX  = "[%(real_name)s] "
 # DEFAULT_SUBJECT_PREFIX = "[%(real_name)s %%d]" # for numbering
 DEFAULT_MSG_HEADER = ""
-DEFAULT_MSG_FOOTER = """_______________________________________________
+DEFAULT_MSG_FOOTER = """-- 
 %(real_name)s mailing list
 %(real_name)s@%(host_name)s
 %(web_page_url)slistinfo%(cgiext)s/%(_internal_name)s
@@ -1104,7 +1205,9 @@ DEFAULT_DMARC_QUARANTINE_MODERATION_ACTION = Yes
 
 # Default action for posts whose From: address domain has a DMARC policy of
 # reject or quarantine.  See DEFAULT_FROM_IS_LIST below.  Whatever is set as
-# the default here precludes the list owner from setting a lower value.
+# the default here precludes the list owner from setting a lower value, however
+# an existing list won't be changed until the first time "Submit Your Changes"
+# is pressed on the list's Privacy options... -> Sender filters page.
 # 0 = Accept
 # 1 = Munge From
 # 2 = Wrap Message
@@ -1119,7 +1222,7 @@ DEFAULT_DMARC_MODERATION_ACTION = 0
 # with a stronger DMARC policy if such a policy would result in message
 # modification because dmarc_moderation_action is 1 or 2.  Thus, there is
 # a list setting to apply dmarc_moderaction_action of 1 or 2 to messages
-# From: domains with DMARC p=none.  Setting this to Yes is only effective if 
+# From: domains with DMARC p=none.  Setting this to Yes is only effective if
 # dmarc_quarantine_moderaction_action is also Yes.  The following is the
 # default for this setting for new lists.
 DEFAULT_DMARC_NONE_MODERATION_ACTION = No
@@ -1155,7 +1258,7 @@ DMARC_ORGANIZATIONAL_DOMAIN_DATA_URL = \
 #                                     (0 to disable).
 DEFAULT_MEMBER_VERBOSITY_INTERVAL = 300
 DEFAULT_MEMBER_VERBOSITY_THRESHOLD = 0
- 
+
 # This controls how often to clean old post time entries from the dictionary
 # used to implement the member verbosity feature. This is a compromise between
 # using resources for cleaning and allowing the dictionary to grow very large.
@@ -1355,6 +1458,13 @@ OWNERS_CAN_PRESERVE_FILTERED_MESSAGES = Yes
 # Check for administrivia in messages sent to the main list?
 DEFAULT_ADMINISTRIVIA = Yes
 
+# The process which avoids sending a list copy of a message to a member who
+# is also directly addressed in To: or Cc: can drop the address from Cc: to
+# avoid growing a long Cc: list in long threads.  This can be undesirable as
+# it can break DKIM signatures and possibly cause confusion.  To avoid changes
+# to Cc: headers, set the list's drop_cc to No.
+DEFAULT_DROP_CC = Yes
+
 
 
 #####
@@ -1367,7 +1477,10 @@ DEFAULT_NONDIGESTABLE = Yes
 # Will list be available in digested form?
 DEFAULT_DIGESTABLE = Yes
 DEFAULT_DIGEST_HEADER = ""
-DEFAULT_DIGEST_FOOTER = DEFAULT_MSG_FOOTER
+DEFAULT_DIGEST_FOOTER = """%(real_name)s mailing list
+%(real_name)s@%(host_name)s
+%(web_page_url)slistinfo%(cgiext)s/%(_internal_name)s
+"""
 
 DEFAULT_DIGEST_IS_DEFAULT = No
 DEFAULT_MIME_IS_DEFAULT_DIGEST = No
@@ -1478,6 +1591,9 @@ PENDING_REQUEST_LIFE = days(3)
 DELIVERY_RETRY_PERIOD = days(5)
 
 # How long should we wait before we retry a temporary delivery failure?
+# Because RetryRunner sleeps for 15 minutes between processes of its queue,
+# whatever is put here is effectively rounded up to the next integer multiple
+# of 15 minutes.
 DELIVERY_RETRY_WAIT = hours(1)
 
 
@@ -1693,6 +1809,7 @@ add_language('cs',    _('Czech'),               'iso-8859-2',  'ltr')
 add_language('da',    _('Danish'),              'iso-8859-1',  'ltr')
 add_language('de',    _('German'),              'iso-8859-1',  'ltr')
 add_language('en',    _('English (USA)'),       'us-ascii',    'ltr')
+add_language('eo',    _('Esperanto'),           'utf-8',       'ltr')
 add_language('es',    _('Spanish (Spain)'),     'iso-8859-1',  'ltr')
 add_language('et',    _('Estonian'),            'iso-8859-15', 'ltr')
 add_language('eu',    _('Euskara'),             'iso-8859-15', 'ltr') # Basque
